@@ -7,6 +7,8 @@ from contextlib import closing
 from functools import wraps
 import kenji.sql as sql
 
+__all__ = ['V', 'Query']
+
 
 class V(object):
     """
@@ -15,17 +17,58 @@ class V(object):
     Gremlin queries.
     """
 
-    def __init__(self, value=None):
+    def __init__(self, src=None, relation=None, dst=None):
         """
         Creates a new ``V`` object.
 
-        :param value: Defaults to none, a source node.
+        :param src: Defaults to None, a source node.
+        :param relation: The relation, defaults to None.
+        :param dst: A destination node, defaults to None.
         """
-        self.src = value
-        self.relation = None
-        self.dst = None
+        self.src = src
+        self.relation = relation
+        self.dst = dst
 
-    def __call__(self, value):
+    def __ge__(self, other):
+        """
+        Create a new edge which source node is the
+        source node of the edge on the left, and the
+        destination node is the source node of the one
+        on the right. Example:
+
+            >>> z = V(1) >= V(2)
+            >>> z.src == 1 and z.dst == 2
+            True
+
+        :param other: The other edge.
+        """
+        v = V(self.src)
+        v.dst = other.src
+        return v
+
+    def __le__(self, other):
+        """
+        Pragmatically creates another edge object-
+        best explained by example:
+
+            >>> z = V(2) <= V(1)
+            >>> z.dst == 2 and z.src == 1
+            True
+
+        :param other: The other edge.
+        """
+        v = V(other.src)
+        v.dst = self.src
+        return v
+
+    def __repr__(self):
+        return '(%s)-[%s]->(%s)' % (
+            '*' if self.src is None else self.src,
+            '*' if not self.relation else ':%s' % (self.relation),
+            '*' if self.dst is None else self.dst
+        )
+
+    def __call__(self, value=None):
         """
         Assign the destination node to a given value.
 
@@ -55,40 +98,28 @@ class Query(object):
         :param db: A SQLite Connection object.
         """
         self.db = db
-        self.sql = []
+        self.query = []
         self.params = []
 
-    def __call__(self, query):
+    def __call__(self, edge):
         """
         Make a query that pulls either the source or
         destination node depending on the given node
-        query.
+        query. The relation must be specified on the
+        node query.
 
-        :param query: The node query.
+        :param edge: An edge query.
         """
-        relation = query.relation
-        src = query.src
+        relation = edge.relation
+        src, dst = edge.src, edge.dst
         statement, params = (
-            sql.inverse_relationship(query.dst, relation) if src is None else
+            sql.inverse_relationship(dst, relation) if src is None else
             sql.forwards_relationship(src, relation)
         )
-        self.sql.append(statement)
-        for parameter in params:
-            self.params.append(parameter)
+        self.query.append(statement)
+        self.params.extend(params)
         return self
 
-    def exists(self, edge):
-        """
-        Checks if an edge exists.
-
-        :param edge: The edge to check.
-        """
-        cursor = self.db.execute(
-            *sql.select_one_relation(edge.src, edge.relation, edge.dst)
-        )
-        with closing(cursor):
-            return bool(tuple(cursor))
-
     @property
     def union(self):
         """
@@ -96,7 +127,7 @@ class Query(object):
         the internal SQL string and returns the query
         object.
         """
-        self.sql.append('UNION')
+        self.query.append('UNION')
         return self
 
     @property
@@ -106,7 +137,7 @@ class Query(object):
         of the internal SQL string and returns the query
         object.
         """
-        self.sql.append('INTERSECT')
+        self.query.append('INTERSECT')
         return self
 
     @property
@@ -116,13 +147,13 @@ class Query(object):
         of the internal SQL string and returns the query
         object.
         """
-        self.sql.append('EXCEPT')
+        self.query.append('EXCEPT')
         return self
 
     def __iter__(self):
-        sql = '\n'.join(self.sql)
-        cursor = self.db.execute(sql, self.params)
-        with closing(cursor):
+        statement = '\n'.join(self.query)
+        with closing(self.db.cursor()) as cursor:
+            cursor.execute(statement, self.params)
             for item in cursor:
                 yield item[0]
 
@@ -134,7 +165,7 @@ class Query(object):
 
         :param count: The integer limit.
         """
-        self.sql.append('LIMIT %d' % (count))
+        self.query.append('LIMIT %d' % (count))
         return self
 
     @property
@@ -144,14 +175,14 @@ class Query(object):
         the internal SQL query and returns the next
         node yielded by performing the query.
         """
-        return next(iter(self.limit(1)))
+        try:
+            return next(iter(self.limit(1)))
+        except StopIteration:
+            return
 
     @property
     def count(self):
         """
         Count the number of nodes returned in a query.
         """
-        counter = 0
-        for _ in self:
-            counter += 1
-        return counter
+        return sum(1 for row in self)
