@@ -1,6 +1,22 @@
 from kenji import Graph, V
 from contextlib import closing
 from sqlite3 import ProgrammingError
+from threading import Thread
+
+
+def test_concurrency(graph):
+    def store(x):
+        def function():
+            graph.store(V(1).knows(x))
+        return function
+
+    stored = (5, 6, 7, 8)
+    threads = [Thread(target=store(i)) for i in stored]
+    [thread.start() for thread in threads]
+    [thread.join() for thread in threads]
+
+    for i in stored:
+        assert graph.exists(V(1).knows(i))
 
 
 def test_store():
@@ -11,8 +27,8 @@ def test_store():
 
 def test_unsafe():
     graph = Graph(unsafe=True)
-    cursor = graph.db.execute('PRAGMA synchronous')
-    with closing(cursor):
+    with closing(graph.db.cursor()) as cursor:
+        cursor.execute('PRAGMA synchronous')
         assert not next(cursor)[0]
 
 
@@ -30,17 +46,16 @@ def test_delete(graph):
 
 def test_close(graph):
     graph.close()
-    assert graph.closed
     try:
         graph.db.execute('SELECT * FROM knows;')
-        assert False, 'connection is not closed!'
+        raise AssertionError('connection is not closed!')
     except ProgrammingError:
         pass
 
 
 def test_graph_relation(graph):
-    assert graph.relation_between('person', V(1)(2)) == ['knows', 'likes']
-    assert graph.relation_between('person', V(0)(2)) == []
+    assert graph.relation_between('person', V(1) >= V(2)) == ['knows', 'likes']
+    assert graph.relation_between('person', V(0) >= V(2)) == []
 
 
 def test_graph_exists(graph):
