@@ -12,6 +12,7 @@ def test_select(graph):
 def test_first(graph):
     assert graph.select(V(2).knows).first in (1, 5)
     assert 2 <= graph.select(V(1).knows).first <= 4
+    assert not graph.select(V(10).knows).first
 
 
 def test_intersection(graph):
@@ -39,3 +40,25 @@ def test_count(graph):
 def test_limit(graph):
     assert len(list(graph.select(V(1).knows).limit(2))) == 2
     assert len(list(graph.select(V(2).knows).limit(1))) == 1
+
+
+def test_v_special():
+    v = V(1) >= V(2)
+    assert v.src == 1
+    assert v.dst == 2
+
+    v = V(3) <= V(2)
+    assert v.src == 2
+    assert v.dst == 3
+
+    v = V(3, 'follows', 2)
+    assert v.src == 3 and v.dst == 2
+    assert v.relation == 'follows'
+
+
+def test_v_repr():
+    assert repr(V(1).knows(2)) == '(1)-[:knows]->(2)'
+    assert repr(V().knows(2))  == '(*)-[:knows]->(2)'
+    assert repr(V(1).knows)    == '(1)-[:knows]->(*)'
+    assert repr(V().knows)     == '(*)-[:knows]->(*)'
+    assert repr(V()) == '(*)-[*]->(*)'
